aboutsummaryrefslogtreecommitdiffstats
path: root/Software/Visual_Studio/Tango.PMR/MachineStatus/SetInkAutoFillingModeRequest.cs
diff options
context:
space:
mode:
authorRoy <Roy.mail.net@gmail.com>2022-07-06 20:02:42 +0300
committerRoy <Roy.mail.net@gmail.com>2022-07-06 20:02:42 +0300
commitcb84ea0240829179a36f6fdcce378154e6abc03e (patch)
tree6ce7421d8ac4340ca313de46bb9103c99139a0ef /Software/Visual_Studio/Tango.PMR/MachineStatus/SetInkAutoFillingModeRequest.cs
parentbef396de524d16618dc532ac9b797055e3bae883 (diff)
downloadTango-cb84ea0240829179a36f6fdcce378154e6abc03e.tar.gz
Tango-cb84ea0240829179a36f6fdcce378154e6abc03e.zip
Updated required PMR for new Auto Ink Filling default mode.
Diffstat (limited to 'Software/Visual_Studio/Tango.PMR/MachineStatus/SetInkAutoFillingModeRequest.cs')
-rw-r--r--Software/Visual_Studio/Tango.PMR/MachineStatus/SetInkAutoFillingModeRequest.cs38
1 files changed, 19 insertions, 19 deletions
diff --git a/Software/Visual_Studio/Tango.PMR/MachineStatus/SetInkAutoFillingModeRequest.cs b/Software/Visual_Studio/Tango.PMR/MachineStatus/SetInkAutoFillingModeRequest.cs
index d41234d99..cfc1b7d40 100644
--- a/Software/Visual_Studio/Tango.PMR/MachineStatus/SetInkAutoFillingModeRequest.cs
+++ b/Software/Visual_Studio/Tango.PMR/MachineStatus/SetInkAutoFillingModeRequest.cs
@@ -23,13 +23,13 @@ namespace Tango.PMR.MachineStatus {
byte[] descriptorData = global::System.Convert.FromBase64String(
string.Concat(
"CiJTZXRJbmtBdXRvRmlsbGluZ01vZGVSZXF1ZXN0LnByb3RvEhdUYW5nby5Q",
- "TVIuTWFjaGluZVN0YXR1cyIwChxTZXRJbmtBdXRvRmlsbGluZ01vZGVSZXF1",
- "ZXN0EhAKCERpc2FibGVkGAEgASgIQiMKIWNvbS50d2luZS50YW5nby5wbXIu",
- "bWFjaGluZXN0YXR1c2IGcHJvdG8z"));
+ "TVIuTWFjaGluZVN0YXR1cyIuChxTZXRJbmtBdXRvRmlsbGluZ01vZGVSZXF1",
+ "ZXN0Eg4KBkVuYWJsZRgBIAEoCEIjCiFjb20udHdpbmUudGFuZ28ucG1yLm1h",
+ "Y2hpbmVzdGF0dXNiBnByb3RvMw=="));
descriptor = pbr::FileDescriptor.FromGeneratedCode(descriptorData,
new pbr::FileDescriptor[] { },
new pbr::GeneratedClrTypeInfo(null, new pbr::GeneratedClrTypeInfo[] {
- new pbr::GeneratedClrTypeInfo(typeof(global::Tango.PMR.MachineStatus.SetInkAutoFillingModeRequest), global::Tango.PMR.MachineStatus.SetInkAutoFillingModeRequest.Parser, new[]{ "Disabled" }, null, null, null)
+ new pbr::GeneratedClrTypeInfo(typeof(global::Tango.PMR.MachineStatus.SetInkAutoFillingModeRequest), global::Tango.PMR.MachineStatus.SetInkAutoFillingModeRequest.Parser, new[]{ "Enable" }, null, null, null)
}));
}
#endregion
@@ -60,7 +60,7 @@ namespace Tango.PMR.MachineStatus {
[global::System.Diagnostics.DebuggerNonUserCodeAttribute]
public SetInkAutoFillingModeRequest(SetInkAutoFillingModeRequest other) : this() {
- disabled_ = other.disabled_;
+ enable_ = other.enable_;
}
[global::System.Diagnostics.DebuggerNonUserCodeAttribute]
@@ -68,14 +68,14 @@ namespace Tango.PMR.MachineStatus {
return new SetInkAutoFillingModeRequest(this);
}
- /// <summary>Field number for the "Disabled" field.</summary>
- public const int DisabledFieldNumber = 1;
- private bool disabled_;
+ /// <summary>Field number for the "Enable" field.</summary>
+ public const int EnableFieldNumber = 1;
+ private bool enable_;
[global::System.Diagnostics.DebuggerNonUserCodeAttribute]
- public bool Disabled {
- get { return disabled_; }
+ public bool Enable {
+ get { return enable_; }
set {
- disabled_ = value;
+ enable_ = value;
}
}
@@ -92,14 +92,14 @@ namespace Tango.PMR.MachineStatus {
if (ReferenceEquals(other, this)) {
return true;
}
- if (Disabled != other.Disabled) return false;
+ if (Enable != other.Enable) return false;
return true;
}
[global::System.Diagnostics.DebuggerNonUserCodeAttribute]
public override int GetHashCode() {
int hash = 1;
- if (Disabled != false) hash ^= Disabled.GetHashCode();
+ if (Enable != false) hash ^= Enable.GetHashCode();
return hash;
}
@@ -110,16 +110,16 @@ namespace Tango.PMR.MachineStatus {
[global::System.Diagnostics.DebuggerNonUserCodeAttribute]
public void WriteTo(pb::CodedOutputStream output) {
- if (Disabled != false) {
+ if (Enable != false) {
output.WriteRawTag(8);
- output.WriteBool(Disabled);
+ output.WriteBool(Enable);
}
}
[global::System.Diagnostics.DebuggerNonUserCodeAttribute]
public int CalculateSize() {
int size = 0;
- if (Disabled != false) {
+ if (Enable != false) {
size += 1 + 1;
}
return size;
@@ -130,8 +130,8 @@ namespace Tango.PMR.MachineStatus {
if (other == null) {
return;
}
- if (other.Disabled != false) {
- Disabled = other.Disabled;
+ if (other.Enable != false) {
+ Enable = other.Enable;
}
}
@@ -144,7 +144,7 @@ namespace Tango.PMR.MachineStatus {
input.SkipLastField();
break;
case 8: {
- Disabled = input.ReadBool();
+ Enable = input.ReadBool();
break;
}
}